<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>Aide</name>
    <message>
        <location filename="../Ui_help.py" line="144"/>
        <source>Aide</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="143"/>
        <source>Mode d&apos;emploi</source>
        <translation>Ordens para uso</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="150"/>
        <source>A propos</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="145"/>
        <source>ScolaSync, pour gerer les fichiers des baladeurs</source>
        <translation>ScolaSync, para a gestão de ficheiros dos leitores de MP3</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_help.py" line="146"/>
        <source>Numero de version :</source>
        <translation>Número de versão :</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="147"/>
        <source>Auteurs</source>
        <translation>Autores</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="148"/>
        <source>Licence</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="149"/>
        <source>Langues et traductions</source>
        <translation>Idiomas e traduções</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="151"/>
        <source>Fermer</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="130"/>
        <source>Choix de fichiers à supprimer</source>
        <translation>Escolha dos ficheiros a suprimir</translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="131"/>
        <source>Zone de recherche</source>
        <translation>Zona de pesquisa</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="132"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Répertoire des &lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;documents de &lt;br /&gt;travail&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;(new line)
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;(new line)
p, li { white-space: pre-wrap; }(new line)
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;(new line)
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Pasta dos &lt;/p&gt;(new line)
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;documentos de &lt;br /&gt;travail&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="138"/>
        <source>Le répertoire des clés&lt;br&gt;où se trouvent les&lt;br&gt;documents de travail</source>
        <translation>A pasta das chaves&lt;br&gt;aonde se encontram&lt;br&gt;os documentos de trabalho</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="139"/>
        <source>Le répertoire des clés où se trouvent les documents de travail</source>
        <translation>A pasta das chaves aonde se encontram os documentos de trabalho</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="140"/>
        <source>Choix de clé modèle</source>
        <translation>Escolha da chave modelo</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="142"/>
        <source>Choisir une des clés</source>
        <translation>Escolher uma das chaves</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="143"/>
        <source>Liste de fichiers à traiter (jokers autorisés)</source>
        <translation>Lista de ficheiros a tratar (jokers autorizados)</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="145"/>
        <source>Supprimer l&apos;item sélectionné</source>
        <translation>Suprimir o elemento selecionado</translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="157"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="148"/>
        <source>Écrire le nom d&apos;un fichier ou d&apos;un répertoire.&lt;br&gt;Jokers autorisés</source>
        <translation>Escrever o nome de um ficheiro ou de uma pasta.&lt;br&gt;Jokers autorizados</translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="150"/>
        <source>Ajouter un fichier ou un filtre</source>
        <translation>Acrescentar um ficheiro ou um filtro</translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="153"/>
        <source>Rechercher (fichier) ...</source>
        <translation>Procurar (ficheiro) ...</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="156"/>
        <source>Rechercher (répertoire) ...</source>
        <translation>Procurar (pasta) ...</translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="57"/>
        <source>Preferences de ScolaSync</source>
        <translation>Preferências de ScolaSync</translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="58"/>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="60"/>
        <source>Les cases à cocher permettent de n&apos;agir que sur une part des baladeurs</source>
        <translation>As casas a assinalar permitem só de agir numa parte dos leitores</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="61"/>
        <source>Utiliser des cases à cocher pour désigner les baladeurs</source>
        <translation>Utilizar casas a assinalar para designar os leitores</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="62"/>
        <source>Répertoire pour les travaux :</source>
        <translation>Pasta para os trabalhos :</translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="63"/>
        <source>Travail</source>
        <translation>Trabalho</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="174"/>
        <source>Choix des fichiers à copier</source>
        <translation>Escolha dos ficheiros a copiar</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="175"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="176"/>
        <source>Ordinateur</source>
        <translation>Computador</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="178"/>
        <source>Disque dur</source>
        <translation>Disco duro</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="180"/>
        <source>Répertoire de destination des baladeurs</source>
        <translation>Pasta de destinação dos leitores</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="182"/>
        <source>Répertoire de destination sur les baladeurs,&lt;br&gt;peut être modifié dans les préférences</source>
        <translation>Pasta de destinação nos leitores,&lt;br&gt;pode ser modificada nas preferênçias</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="184"/>
        <source>Baladeur</source>
        <translation>Leitor</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="187"/>
        <source>Disque flash</source>
        <translation>Disco flash</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="190"/>
        <source>Cle USB</source>
        <translation>Chave USB</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="192"/>
        <source>Taille totale :</source>
        <translation>Tamanho total :</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="194"/>
        <source>Ajouter a la liste</source>
        <translation>Acrenscentar à lista</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="197"/>
        <source>Retirer de la liste</source>
        <translation>Tirar da lista</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="199"/>
        <source>Abandonner</source>
        <translation>Abandonar</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="200"/>
        <source>Continuer ...</source>
        <translation>Continuar...</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="154"/>
        <source>Double-clic non pris en compte</source>
        <translation>Clique-duplo não é considerado</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="154"/>
        <source>pas d&apos;action pour l&apos;attribut %1</source>
        <translation>sem ação para o atributo %1</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="238"/>
        <source>Choix de fichiers à supprimer (jokers autorisés)</source>
        <translation>Escolha de ficheiros a suprimir (jokers autorizados)</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="285"/>
        <source>Aucun fichier sélectionné</source>
        <translation>Nenhum ficheiro selecionado</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="285"/>
        <source>Veuillez choisir au moins un fichier</source>
        <translation>Escolha pelo menos um ficheiro</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="279"/>
        <source>Choix de fichiers à copier</source>
        <translation>Escolha de ficheiros a copiar</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="280"/>
        <source>Choix de fichiers à copier depuis les baladeurs</source>
        <translation>Escolha de ficheiros a copiar a partir dos leitores</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="281"/>
        <source>Choix de la destination ...</source>
        <translation>Escolha do destino ...</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="293"/>
        <source>Choisir un répertoire de destination</source>
        <translation>Escolher uma pasta de destinação</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="312"/>
        <source>Voir les copies</source>
        <translation>Ver os devers</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="312"/>
        <source>Voulez-vous voir les fichiers copiés ?</source>
        <translation>Quer ver os ficheiros copiados ?</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="317"/>
        <source>Destination manquante</source>
        <translation>Falta de destinação</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="317"/>
        <source>Veuillez choisir une destination pour la copie des fichiers</source>
        <translation>Escolha um destino para a cópia dos ficheiros</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="" line="1768190543"/>
        <source>Liste de périphériques modifiée pour Scolasync</source>
        <translation type="obsolete">Lista de periphéricos modificada para o Scolasync</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="" line="1768190543"/>
        <source>Une clé USB ou un baladeur numérique au moins a change de statut. Vérifiez éventuellement la liste des périphériques de Scolasync</source>
        <translation type="obsolete">Pelo menos uma chave USB ou um leitor numérico mudou de estatuto. Verifique eventualmente a lista dos periphéricos de Scolasync</translation>
    </message>
    <message>
        <location filename="../copyToDialog1.py" line="162"/>
        <source>%s kilo-octets</source>
        <translation>%s kilobytes</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../copyToDialog1.py" line="165"/>
        <source>%s méga-octets</source>
        <translation>%s megabytes</translation>
    </message>
    <message>
        <location filename="../copyToDialog1.py" line="168"/>
        <source>%s giga-octets</source>
        <translation>%s gigabytes</translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="161"/>
        <source>inconnu</source>
        <translation>desconhecido</translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="202"/>
        <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
        <translation>A chave %1&lt;br&gt;não està identificada, dê o nome do dono</translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="203"/>
        <source>Entrer un nom</source>
        <translation>Escreva um nome</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="243"/>
        <source>Vous allez effacer plusieurs baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context encoding="UTF-8">
    <name>Main</name>
    <message encoding="UTF-8">
        <location filename="../help.py" line="39"/>
        <source>Version numéro %1.%2</source>
        <translation>Versão número %1.%2</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="337"/>
        <source>Démontage des baladeurs</source>
        <translation>Desmontagem dos leitores</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="337"/>
        <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
        <translation>Tem a certeza de querer desmontar todos os leitores assinalados ?</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="477"/>
        <source>Cocher ou décocher cette case en cliquant.</source>
        <translation>Assinalar ou desmarcar esta casa clicando.</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="479"/>
        <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
        <translation>Dono da chave ou do leitor ;&lt;br&gt;&lt;b&gt;Clique-duplo&lt;/b&gt; para modificar.</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="481"/>
        <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
        <translation>Ponto de montagem da chave ou do leitor ; &lt;br&gt;&lt;b&gt;Clique-duplo&lt;/b&gt; para ver os ficheiros.</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="483"/>
        <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
        <translation>Capacidade da chave USB ou do leitor en kB ;&lt;br&gt;&lt;b&gt;Clique-duplo&lt;/b&gt; para ver o espaço ocupado.</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="485"/>
        <source>Fabricant de la clé USB ou du baladeur.</source>
        <translation>Fabricante da chave USB ou do leitor.</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="487"/>
        <source>Modèle de la clé USB ou du baladeur.</source>
        <translation>Modelo da chave ou do leitor.</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="489"/>
        <source>Numéro de série de la clé USB ou du baladeur.</source>
        <translation>Número de série da chave ou do leitor.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../Ui_mainWindow.py" line="119"/>
        <source>ScolaSync</source>
        <translation>Scolasync</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="120"/>
        <source>Actions</source>
        <translation>Ações</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="42"/>
        <source>Copier depuis les cles</source>
        <translation type="obsolete">Copiar a partir dos leitores</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="143"/>
        <source>...</source>
        <translation>... </translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="54"/>
        <source>Copier vers les cles</source>
        <translation type="obsolete">Copiar para os leitores</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="66"/>
        <source>Supprimer dans les clés</source>
        <translation type="obsolete">Suprimir nos leitores</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="78"/>
        <source>Demonter les cles</source>
        <translation type="obsolete">Desmontar os leitores</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="90"/>
        <source>Preferences</source>
        <translation type="obsolete">Preferéncias</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="142"/>
        <source>Aide</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../Ui_diskFull.py" line="56"/>
        <source>Disk size</source>
        <translation>Tamanho do disco</translation>
    </message>
    <message>
        <location filename="../Ui_diskFull.py" line="58"/>
        <source>total size</source>
        <translation>Tamanho total</translation>
    </message>
    <message>
        <location filename="../Ui_diskFull.py" line="59"/>
        <source>Used</source>
        <translation>Utilizado</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="137"/>
        <source>Force à recompter les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="140"/>
        <source>Affiche le nombre de baladeurs connectés</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="122"/>
        <source>Copier depuis les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="125"/>
        <source>Copier vers les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="128"/>
        <source>Effacer des fichiers ou des dossiers dans les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="131"/>
        <source>Demonter les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="134"/>
        <source>Préférences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context encoding="UTF-8">
    <name>diskFull</name>
    <message encoding="UTF-8">
        <location filename="../diskFull.py" line="49"/>
        <source>Place totale : %1 kilo-octets</source>
        <translation>Lugar total : %1 kilobytes</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../diskFull.py" line="50"/>
        <source>Place utilisée : %1 kilo-octets</source>
        <translation>Lugar utilizado : %1 kilobytes</translation>
    </message>
</context>
<context>
    <name>uDisk</name>
    <message>
        <location filename="../usbDisk.py" line="63"/>
        <source>point de montage</source>
        <translation>Ponto de montagem</translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="64"/>
        <source>taille</source>
        <translation>tamanho</translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="65"/>
        <source>vendeur</source>
        <translation type="obsolete">vendedor</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../usbDisk.py" line="66"/>
        <source>modèle de disque</source>
        <translation>modelo de disco</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../usbDisk.py" line="67"/>
        <source>numéro de série</source>
        <translation>número de série</translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="70"/>
        <source>cocher</source>
        <translation>assinalar</translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="145"/>
        <source>owner</source>
        <translation>dono</translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="65"/>
        <source>marque</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
